==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/panel/lxqt-panel_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Tilføj plugins</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Søg:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Tilføj widget</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(kan kun køre én instans af gangen)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Konfigurationspanel</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Konfigurér panel</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Ikonstørrelse:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Længde:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Negative pixel-værdier sætter panelets længe til så mange pixel mindre end den tilgængelige skærmplads.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;F.eks. &quot;Længde&quot; sæt til -100px, skærmstørrelse er 1000px, så vil den rigtige panellængde blive 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>Række antal:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Justering og placering</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="262"/>
        <location filename="../../../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Nul betyder ingen animation</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="288"/>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Animationens varighed:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="219"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <location filename="../../../config/configpanelwidget.cpp" line="209"/>
        <source>Center</source>
        <translation>Centereret</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="229"/>
        <location filename="../../../config/configpanelwidget.cpp" line="204"/>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="301"/>
        <location filename="../../../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>Brugerdefineret udseende</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>Skriftfarve:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>Baggrundsfarve:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>Baggrundens opacity:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Komposition kræves for panelet kan være gennemsigtigt.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>Baggrundsbillede:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Justering:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>Placering:</translation>
    </message>
    <message>
        <source>Auto-hide</source>
        <translation type="vanished">Skjul automatisk</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="168"/>
        <source>Top of desktop</source>
        <translation>Øverst på skrivebordet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="169"/>
        <source>Left of desktop</source>
        <translation>Til venstre på skrivebordet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="170"/>
        <source>Right of desktop</source>
        <translation>Til højre på skrivebordet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="171"/>
        <source>Bottom of desktop</source>
        <translation>Nederst på skrivebordet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="180"/>
        <source>Top of desktop %1</source>
        <translation>Øverst på skrivebord %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="181"/>
        <source>Left of desktop %1</source>
        <translation>Til venstre på skrivebord %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="182"/>
        <source>Right of desktop %1</source>
        <translation>Til højre på skrivebord %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="183"/>
        <source>Bottom of desktop %1</source>
        <translation>Nederst på skrivebord %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="208"/>
        <source>Top</source>
        <translation>Øverst</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="210"/>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="368"/>
        <location filename="../../../config/configpanelwidget.cpp" line="384"/>
        <source>Pick color</source>
        <translation>Vælg farve</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Billeder (*.png *.gif *.jpg)</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Pick image</source>
        <translation>Vælg billede</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Konfigurér plugins</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Bemærk: ændringer foretaget på denne side kan ikke nulstilles.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Flyt op</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Flyt ned</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Konfigurér</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1066"/>
        <location filename="../../../lxqtpanel.cpp" line="1091"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1094"/>
        <source>Configure Panel</source>
        <translation>Konfigurér panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1099"/>
        <source>Manage Widgets</source>
        <translation>Håndtér widgets</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1105"/>
        <source>Add New Panel</source>
        <translation>Tilføj nyt panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1112"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation type="unfinished">Fjern panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1117"/>
        <source>Lock This Panel</source>
        <translation>Lås dette panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1259"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation type="unfinished">Fjern panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1260"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Fjernelse af et panel kan ikke fortrydes.
Vil du fjerne dette panel?</translation>
    </message>
    <message>
        <source>Remove Panel</source>
        <translation type="vanished">Fjern panel</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="416"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Konfigurér &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="421"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Flyt &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="429"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Fjern &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>Brug alternativ konfigurationsfil.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>Konfigurationsfil</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/panel/lxqt-panel_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Tilføj plugins</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Søg:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Tilføj widget</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(kan kun køre én instans af gangen)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Konfigurationspanel</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Konfigurér panel</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Ikonstørrelse:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Længde:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Negative pixel-værdier sætter panelets længe til så mange pixel mindre end den tilgængelige skærmplads.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;F.eks. &quot;Længde&quot; sæt til -100px, skærmstørrelse er 1000px, så vil den rigtige panellængde blive 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>Række antal:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Justering og placering</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="262"/>
        <location filename="../../../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Nul betyder ingen animation</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="288"/>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Animationens varighed:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="219"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <location filename="../../../config/configpanelwidget.cpp" line="209"/>
        <source>Center</source>
        <translation>Centereret</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="229"/>
        <location filename="../../../config/configpanelwidget.cpp" line="204"/>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>Skjul &amp;automatisk</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="301"/>
        <location filename="../../../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>Nul betyder ingen forsinkelse</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>Vis med forsinkelse:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>Tillad ikke maksimerede vinduer at gå under panel-vinduet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation>Reserver plads på skærm</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>Brugerdefineret udseende</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>Skriftfarve:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>Baggrundsfarve:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>Baggrundens opacity:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Komposition kræves for at panelet kan være gennemsigtigt.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>Baggrundsbillede:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Justering:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>Placering:</translation>
    </message>
    <message>
        <source>Auto-hide</source>
        <translation type="vanished">Skjul automatisk</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="168"/>
        <source>Top of desktop</source>
        <translation>Øverst på skrivebordet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="169"/>
        <source>Left of desktop</source>
        <translation>Til venstre på skrivebordet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="170"/>
        <source>Right of desktop</source>
        <translation>Til højre på skrivebordet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="171"/>
        <source>Bottom of desktop</source>
        <translation>Nederst på skrivebordet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="180"/>
        <source>Top of desktop %1</source>
        <translation>Øverst på skrivebord %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="181"/>
        <source>Left of desktop %1</source>
        <translation>Til venstre på skrivebord %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="182"/>
        <source>Right of desktop %1</source>
        <translation>Til højre på skrivebord %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="183"/>
        <source>Bottom of desktop %1</source>
        <translation>Nederst på skrivebord %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="208"/>
        <source>Top</source>
        <translation>Øverst</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="210"/>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="368"/>
        <location filename="../../../config/configpanelwidget.cpp" line="384"/>
        <source>Pick color</source>
        <translation>Vælg farve</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Billeder (*.png *.gif *.jpg)</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Pick image</source>
        <translation>Vælg billede</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Konfigurér plugins</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Bemærk: ændringer foretaget på denne side kan ikke nulstilles.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Flyt op</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Flyt ned</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Konfigurér</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1068"/>
        <location filename="../../../lxqtpanel.cpp" line="1094"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1097"/>
        <source>Configure Panel</source>
        <translation>Konfigurér panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1102"/>
        <source>Manage Widgets</source>
        <translation>Håndtér widgets</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1108"/>
        <source>Add New Panel</source>
        <translation>Tilføj nyt panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1115"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>Fjern panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1120"/>
        <source>Lock This Panel</source>
        <translation>Lås dette panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1265"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>Fjern panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1266"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Fjernelse af et panel kan ikke fortrydes.
Vil du fjerne dette panel?</translation>
    </message>
    <message>
        <source>Remove Panel</source>
        <translation type="vanished">Fjern panel</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="416"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Konfigurér &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="421"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Flyt &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="429"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Fjern &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>Brug alternativ konfigurationsfil.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>Konfigurationsfil</translation>
    </message>
</context>
</TS>
